==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.nonconformity_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.nonconformity_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Nonconformity }
     * 
     */
    public Nonconformity createNonconformity() {
        return new Nonconformity();
    }

    /**
     * Create an instance of {@link TrackingDetails }
     * 
     */
    public TrackingDetails createTrackingDetails() {
        return new TrackingDetails();
    }

    /**
     * Create an instance of {@link LinearReferenceDetails }
     * 
     */
    public LinearReferenceDetails createLinearReferenceDetails() {
        return new LinearReferenceDetails();
    }

    /**
     * Create an instance of {@link EquipmentDetails }
     * 
     */
    public EquipmentDetails createEquipmentDetails() {
        return new EquipmentDetails();
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.nonconformity_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.nonconformity_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Nonconformity }
     * 
     * @return
     *     the new instance of {@link Nonconformity }
     */
    public Nonconformity createNonconformity() {
        return new Nonconformity();
    }

    /**
     * Create an instance of {@link TrackingDetails }
     * 
     * @return
     *     the new instance of {@link TrackingDetails }
     */
    public TrackingDetails createTrackingDetails() {
        return new TrackingDetails();
    }

    /**
     * Create an instance of {@link LinearReferenceDetails }
     * 
     * @return
     *     the new instance of {@link LinearReferenceDetails }
     */
    public LinearReferenceDetails createLinearReferenceDetails() {
        return new LinearReferenceDetails();
    }

    /**
     * Create an instance of {@link EquipmentDetails }
     * 
     * @return
     *     the new instance of {@link EquipmentDetails }
     */
    public EquipmentDetails createEquipmentDetails() {
        return new EquipmentDetails();
    }

}
